@@ -199,7 +199,10 @@ class R3sponse(object):
 				_error_ = True
 				msg = f"Error: {response['error']}"
 			else: 
-				msg = response["message"]
+				if response.__class__.__name__ in ["Output"]: 
+					msg = str(response)
+				else:
+					msg = response["message"]
 		elif error != None: 
 			msg = f"Error: {error}"
 		else: 
